@@ -48,7 +48,7 @@ def download_deep_catalog():
     deep_oc_dir = pathlib.Path(CONF.deep_oc_dir)
 
     try:
-        repo = git.Repo(deep_oc_dir)
+        git.Repo(deep_oc_dir)
     except git.exc.NoSuchPathError:
         deep_oc_dir.mkdir(parents=True)
         git.Repo.clone_from(CONF.deep_oc_repo, deep_oc_dir)
@@ -65,9 +65,9 @@ def download_deep_catalog():
     # NOTE(aloga): we cannot rely on gitpython to update the submodules, as
     # it fails to update them if the branch is other than main
     subprocess.run(["git", "submodule", "init"],
-                   cwd = deep_oc_dir)
+                   cwd=deep_oc_dir)
     subprocess.run(["git", "submodule", "update", "--recursive"],
-                   cwd = deep_oc_dir)
+                   cwd=deep_oc_dir)
 
 
 @lockutils.synchronized("catalog.lock", external=True)
@@ -113,10 +113,14 @@ async def load_modules_metadata():
 
 
 async def get_dockerhub_tags(session, image):
-    url = f'https://registry.hub.docker.com/v1/repositories/{image}/tags'
-    async with session.get(url, raise_for_status=True) as r:
-        aux = await r.json()
-    return [i['name'] for i in aux]
+    url = f'https://registry.hub.docker.com/v2/repositories/{image}/tags'
+    try:
+        async with session.get(url, raise_for_status=True) as r:
+            aux = await r.json()
+    except aiohttp.client_exceptions.ClientError:
+        LOG.error(f"Cannot get tags from DockerHub {image}")
+        return []
+    return [i['name'] for i in aux["results"]]
 
 
 @lockutils.synchronized("tosca-templates.lock", external=True)
